@@ -42,7 +42,7 @@ class parser_private_c {
   mtx::bytes::buffer_c buffer;
   frame_t current_frame;
   std::deque<frame_t> frames;
-  uint64_t frame_number{}, num_units_in_display_tick{}, time_scale{}, num_ticks_per_picture{};
+  uint64_t frame_number{}, num_units_in_display_tick{}, time_scale{}, num_ticks_per_picture{}, input_pos{};
   mtx_mp_rational_t forced_default_duration, bitstream_default_duration = mtx::rational(1'000'000'000ull, 25);
 
   memory_cptr sequence_header_obu;
@@ -97,17 +97,7 @@ parser_c::get_next_timestamp() {
 
 uint64_t
 parser_c::read_leb128(mtx::bits::reader_c &r) {
-  uint64_t value{};
-
-  for (int idx = 0; idx < 8; ++idx) {
-    auto byte  = r.get_bits(8);
-    value     |= (byte & 0x7f) << (idx * 7);
-
-    if ((byte & 0x80) == 0)
-      break;
-  }
-
-  return value;
+  return r.get_leb128();
 }
 
 uint64_t
@@ -383,13 +373,22 @@ parser_c::parse(unsigned char const *buffer,
 
   r.init(p->buffer.get_buffer(), p->buffer.get_size());
 
-  mxdebug_if(p->debug_parser, fmt::format("debug_parser: start on size {0}\n", buffer_size));
+  mxdebug_if(p->debug_parser, fmt::format("debug_parser: start at {0} size {1}\n", p->input_pos, buffer_size));
+
+  auto last_good_bit_position = r.get_bit_position();
 
   while (r.get_remaining_bits() > 0)
     try {
       if (!parse_obu())
         break;
-    } catch (exception const &ex) {
+      last_good_bit_position = r.get_bit_position();
+
+    } catch (mtx::mm_io::end_of_file_x const &ex) {
+      mxdebug_if(p->debug_parser, fmt::format("debug_parser: end of file exception: {0}\n", ex.what()));
+      r.set_bit_position(last_good_bit_position);
+      break;
+
+    } catch (mtx::exception const &ex) {
       mxdebug_if(p->debug_parser, fmt::format("debug_parser: exception: {0}\n", ex.what()));
       break;
     }
@@ -408,7 +407,8 @@ parser_c::parse_obu() {
     throw obu_without_size_unsupported_x{};
 
   mxdebug_if(p->debug_parser,
-             fmt::format("debug_parser:   at {0} type {1} ({2}) size {3} remaining {4}\n",
+             fmt::format("debug_parser:   at absolute {0} relative {1} type {2} ({3}) size {4} remaining {5}\n",
+                         p->input_pos,
                          start_bit_position / 8,
                          p->obu_type,
                          get_obu_type_name(p->obu_type),
@@ -425,8 +425,10 @@ parser_c::parse_obu() {
   mtx::bits::reader_c sub_r{obu->get_buffer(), obu->get_size()};
   sub_r.set_bit_position(r.get_bit_position() - start_bit_position);
 
-  at_scope_exit_c copy_current_and_seek_to_next_obu([this, next_obu_bit_position, &obu, &keep_obu]() {
+  at_scope_exit_c copy_current_and_seek_to_next_obu([this, start_bit_position, next_obu_bit_position, &obu, &keep_obu]() {
     p->r.set_bit_position(next_obu_bit_position);
+    p->input_pos += (next_obu_bit_position - start_bit_position) / 8;
+
     if (!keep_obu)
       return;
 
@@ -447,17 +449,20 @@ parser_c::parse_obu() {
     auto in_spatial_layer  = !!((p->operating_point_idc >> (*p->spatial_id + 8)) & 1);
 
     if (!in_temporal_layer || !in_spatial_layer) {
+      mxdebug_if(p->debug_parser, fmt::format("debug_parser:     not keeping due to layer; in_temporal_layer {0} in_spatial_layer {1}\n", in_temporal_layer, in_spatial_layer));
       keep_obu = false;
       return true;
     }
   }
 
   if (mtx::included_in(p->obu_type, OBU_PADDING, OBU_REDUNDANT_FRAME_HEADER)) {
+    mxdebug_if(p->debug_parser, fmt::format("debug_parser:     not keeping due to type {0}\n", p->obu_type));
     keep_obu = false;
     return true;
   }
 
   if (p->obu_type == OBU_TEMPORAL_DELIMITER) {
+    mxdebug_if(p->debug_parser, fmt::format("debug_parser:     not keeping due to type being temporal delimiter\n"));
     flush();
     p->seen_frame_header = false;
     keep_obu             = false;
@@ -584,6 +589,8 @@ parser_c::flush() {
     if (frame.is_keyframe && !p->current_frame_contains_sequence_header)
       frame.mem->prepend(p->sequence_header_obu);
 
+    mtx::av1::maybe_shrink_size_fields(*frame.mem);
+
     p->frames.push_back(frame);
   }
 
@@ -695,4 +702,80 @@ parser_c::debug_obu_types(unsigned char const *buffer,
   }
 }
 
+void
+maybe_shrink_size_fields(memory_c &mem) {
+  static debugging_option_c s_debug{"av1_shrink_size_field"};
+
+  if (mem.get_size() < 2)
+    return;
+
+  mxdebug_if(s_debug, fmt::format("start\n"));
+
+  auto buffer      = mem.get_buffer();
+  auto buffer_size = mem.get_size();
+  auto idx_src     = 0u;
+  auto idx_dest    = 0u;
+
+  while ((idx_src + 2) < buffer_size) {
+    try {
+      mxdebug_if(s_debug, fmt::format("  idx_src {0} idx_dest {1} buffer_size {2}\n", idx_src, idx_dest, buffer_size));
+
+      mtx::bits::reader_c r{&buffer[idx_src], buffer_size - idx_src};
+      // See 5.3.2 OBU header syntax
+      r.skip_bits(1 + 4 + 1);
+
+      if (!r.get_bit()) {
+        mxdebug_if(s_debug, fmt::format("  ouff no size field\n"));
+        // copy rest
+        std::memmove(&buffer[idx_dest], &buffer[idx_src], buffer_size - idx_src);
+        idx_dest += buffer_size - idx_src;
+
+        break;
+      }
+
+      r.skip_bit();
+
+      auto obu_size   = r.get_leb128();
+      auto field_size = r.get_bit_position() / 8 - 1u;
+
+      unsigned char new_size_field[9];
+      mtx::bits::writer_c w{new_size_field, 9};
+
+      w.put_leb128(obu_size);
+
+      auto new_field_size = w.get_bit_position() / 8;
+
+      mxdebug_if(s_debug, fmt::format("  obu_size {0} field_size {1} new_field_size {2}\n", obu_size, field_size, new_field_size));
+
+      if ((1 + idx_src + field_size + obu_size) > buffer_size)
+        return;
+
+      auto full_obu_size = 1 + field_size + obu_size;
+
+      if (field_size <= new_field_size) {
+        if (idx_src != idx_dest)
+          std::memmove(&buffer[idx_dest], &buffer[idx_src], full_obu_size);
+
+        idx_src  += full_obu_size;
+        idx_dest += full_obu_size;
+
+        continue;
+      }
+
+      buffer[idx_dest] = buffer[idx_src];
+      std::memcpy(&buffer[idx_dest + 1], new_size_field, new_field_size);
+      std::memmove(&buffer[idx_dest + 1 + new_field_size], &buffer[idx_src + 1 + field_size], obu_size);
+
+      idx_src  += 1 +     field_size + obu_size;
+      idx_dest += 1 + new_field_size + obu_size;
+
+    } catch (mtx::mm_io::end_of_file_x &) {
+    }
+  }
+
+  if (idx_src == idx_dest)
+    return;
+
+  mem.resize(idx_dest);
+}
 }
