@@ -264,7 +264,7 @@ struct qtmp4_demuxer_c {
   memory_cptr stsd;
   unsigned int stsd_non_priv_struct_size;
   uint32_t v_width, v_height, v_bitdepth, v_display_width_flt{}, v_display_height_flt{};
-  uint16_t v_colour_primaries, v_colour_transfer_characteristics, v_colour_matrix_coefficients;
+  uint16_t v_color_primaries, v_color_transfer_characteristics, v_color_matrix_coefficients;
   bool m_hevc_is_annex_b{};
   std::deque<int64_t> references;
   uint32_t a_channels, a_bitdepth;
@@ -300,9 +300,9 @@ struct qtmp4_demuxer_c {
     , v_width{0}
     , v_height{0}
     , v_bitdepth{0}
-    , v_colour_primaries{2}
-    , v_colour_transfer_characteristics{2}
-    , v_colour_matrix_coefficients{2}
+    , v_color_primaries{2}
+    , v_color_transfer_characteristics{2}
+    , v_color_matrix_coefficients{2}
     , a_channels{0}
     , a_bitdepth{0}
     , a_samplerate{0.0}
@@ -377,7 +377,7 @@ struct qtmp4_demuxer_c {
   void check_for_hevc_video_annex_b_bitstream();
 
   void set_packetizer_display_dimensions();
-  void set_packetizer_colour_properties();
+  void set_packetizer_color_properties();
   void set_packetizer_block_addition_mappings();
 
 
