@@ -309,13 +309,14 @@ Settings::RunProgramConfig::name()
   if (!m_name.isEmpty())
     return m_name;
 
-  return m_type == RunProgramType::ExecuteProgram    ? nameForExternalProgram()
-       : m_type == RunProgramType::PlayAudioFile     ? nameForPlayAudioFile()
-       : m_type == RunProgramType::ShutDownComputer  ? QY("Shut down the computer")
-       : m_type == RunProgramType::HibernateComputer ? QY("Hibernate the computer")
-       : m_type == RunProgramType::SleepComputer     ? QY("Sleep the computer")
-       : m_type == RunProgramType::DeleteSourceFiles ? QY("Delete source files for multiplexer jobs")
-       :                                               Q("unknown");
+  return m_type == RunProgramType::ExecuteProgram          ? nameForExternalProgram()
+       : m_type == RunProgramType::PlayAudioFile           ? nameForPlayAudioFile()
+       : m_type == RunProgramType::ShowDesktopNotification ? QY("Show a desktop notification")
+       : m_type == RunProgramType::ShutDownComputer        ? QY("Shut down the computer")
+       : m_type == RunProgramType::HibernateComputer       ? QY("Hibernate the computer")
+       : m_type == RunProgramType::SleepComputer           ? QY("Sleep the computer")
+       : m_type == RunProgramType::DeleteSourceFiles       ? QY("Delete source files for multiplexer jobs")
+       :                                                     Q("unknown");
 }
 
 QString
@@ -873,6 +874,7 @@ Settings::addDefaultRunProgramConfigurations(QSettings &reg) {
   auto numConfigurationsBefore = m_runProgramConfigurations.count();
 
   addDefaultRunProgramConfigurationForType(reg, RunProgramType::PlayAudioFile, [](RunProgramConfig &cfg) { cfg.m_audioFile = App::programRunner().defaultAudioFileName(); });
+  addDefaultRunProgramConfigurationForType(reg, RunProgramType::ShowDesktopNotification, [](RunProgramConfig &cfg) { cfg.m_forEvents = RunAfterJobCompletesSuccessfully | RunAfterJobCompletesWithErrors | RunAfterJobCompletesWithWarnings; });
   addDefaultRunProgramConfigurationForType(reg, RunProgramType::SleepComputer);
   addDefaultRunProgramConfigurationForType(reg, RunProgramType::HibernateComputer);
   addDefaultRunProgramConfigurationForType(reg, RunProgramType::ShutDownComputer);
